@@ -1,4 +1,4 @@
-{-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE FlexibleContexts, BangPatterns #-}
 
 -- |
 -- Module    : Statistics.Sample.Histogram
@@ -71,8 +71,9 @@ histogram_ numBins lo hi xs0 = G.create (GM.replicate numBins 0 >>= bin xs0)
             | otherwise = do
          let x = xs `G.unsafeIndex` i
              b = truncate $ (x - lo) / d
-         GM.write bins b . (+1) =<< GM.read bins b
+         write' bins b . (+1) =<< GM.read bins b
          go (i+1)
+       write' bins b !e = GM.write bins b e
        len = G.length xs
        d = ((hi - lo) * (1 + realToFrac m_epsilon)) / fromIntegral numBins
 {-# INLINE histogram_ #-}
