@@ -1,8 +1,12 @@
+{-# LANGUAGE ScopedTypeVariables #-}
 -- | Helpers for testing
 module Tests.Helpers (
     -- * helpers
     T(..)
   , typeName
+  , Double01(..)
+    -- * IEEE 754
+  , isDenorm
     -- * Generic QC tests
   , monotonicallyIncreases
   , monotonicallyIncreasesIEEE
@@ -16,6 +20,7 @@ module Tests.Helpers (
   ) where
 
 import Data.Typeable
+import Numeric.MathFunctions.Constants (m_tiny)
 import Test.Framework
 import Test.Framework.Providers.HUnit
 import Test.QuickCheck
@@ -32,6 +37,18 @@ typeName = show . typeOf . typeParam
     typeParam :: T a -> a
     typeParam _ = undefined
 
+-- | Check if Double denormalized
+isDenorm :: Double -> Bool
+isDenorm x = let ax = abs x in ax > 0 && ax < m_tiny
+
+-- | Generates Doubles in range [0,1]
+newtype Double01 = Double01 Double
+                   deriving (Show)
+instance Arbitrary Double01 where
+  arbitrary = do
+    (_::Int, x) <- fmap properFraction arbitrary
+    return $ Double01 x
+
 ----------------------------------------------------------------
 -- Generic QC
 ----------------------------------------------------------------
